@@ -17,21 +17,18 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
 #ifndef KCALC_H
 #define KCALC_H
 
-class QPushButton;
-class QRadioButton;
-class QButtonGroup;
-class QHButtonGroup;
-class QWidget;
-class DispLogic;
 class Constants;
-#include <kmainwindow.h>
+class QButtonGroup;
+class KToggleAction;
+
+#include <kxmlguiwindow.h>
 
 /*
   Kcalc basically consist of a class for the GUI (here), a class for
@@ -51,19 +48,49 @@ class Constants;
   operation button is pressed, e.g. "core.Plus(display_number)".
  */
 
-#include "config.h"
+#include "config-kcalc.h"
 
-// IMPORTANT this has to come after ../config.h
+// IMPORTANT this has to come after config-kcalc.h - DF: why?
 #include "kcalc_core.h"
 #include "kcalc_button.h"
 #include "kcalc_const_button.h"
 
-class KCalculator : public KMainWindow
+#include "ui_kcalc.h"
+#include "ui_general.h"
+#include "ui_constants.h"
+#include "ui_colors.h"
+
+class  General: public QWidget, public Ui::General
+{
+public:
+  General( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+class Constants : public QWidget, public Ui::Constants
+{
+public:
+  Constants( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+class Colors : public QWidget, public Ui::Colors
+{
+public:
+  Colors( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+
+class KCalculator : public KXmlGuiWindow, private Ui::KCalculator
 {
     Q_OBJECT
 
 public:
-	KCalculator(QWidget *parent = 0, const char *name = 0);
+	KCalculator(QWidget *parent = 0);
 	~KCalculator();
 
 signals:
@@ -76,36 +103,30 @@ private:
 	void updateGeometry();
 	void setupMainActions(void);
 	void setupStatusbar(void);
-	QWidget *setupNumericKeys(QWidget *parent);
-	void setupLogicKeys(QWidget *parent);
-	void setupLogExpKeys(QWidget *parent);
-	void setupTrigKeys(QWidget *parent);
-	void setupStatisticKeys(QWidget *parent);
-	void setupConstantsKeys(QWidget *parent);
+	void setupKeys();
 	void keyPressEvent(QKeyEvent *e);
 	void keyReleaseEvent(QKeyEvent *e);
 	void set_precision();
 	void set_style();
-	void resetBase(void) { (BaseChooseGroup->find(1))->animateClick();};
+	void resetBase(void) { decRadio->animateClick(); }
 
-	void UpdateDisplay(bool get_amount_from_core = false,
+	void updateDisplay(bool get_amount_from_core = false,
 			   bool store_result_in_history = false);
 
 protected slots:
-    void changeButtonNames();
+void changeButtonNames();
     void updateSettings();
     void set_colors();
     void EnterEqual();
     void showSettings();
     void slotStatshow(bool toggled);
-    void slotTrigshow(bool toggled);
-    void slotExpLogshow(bool toggled);
+    void slotScientificshow(bool toggled);
     void slotLogicshow(bool toggled);
     void slotConstantsShow(bool toggled);   
     void slotShowAll(void);
     void slotHideAll(void);
-    void slotAngleSelected(int number);
-    void slotBaseSelected(int number);
+    void slotAngleSelected(int mode);
+    void slotBaseSelected(int base);
     void slotNumberclicked(int number_clicked);
     void slotEEclicked(void);
     void slotInvtoggled(bool myboolean);
@@ -122,13 +143,13 @@ protected slots:
     void slotSquareclicked(void);
     void slotLnclicked(void);
     void slotPowerclicked(void);
-    void slotMCclicked(void);
+    void slotMemClearclicked(void);
     void slotClearclicked(void);
-    void slotACclicked(void);
+    void slotAllClearclicked(void);
     void slotParenOpenclicked(void);
     void slotParenCloseclicked(void);
     void slotANDclicked(void);
-    void slotXclicked(void);
+    void slotMultiplicationclicked(void);
     void slotDivisionclicked(void);
     void slotORclicked(void);
     void slotXORclicked(void);
@@ -151,91 +172,65 @@ protected slots:
     void slotHyptoggled(bool flag);
     void slotConstclicked(int);
 
-    void slotConstantToDisplay(int constant);
-    void slotChooseScientificConst0(int option);
-    void slotChooseScientificConst1(int option);
-    void slotChooseScientificConst2(int option);
-    void slotChooseScientificConst3(int option);
-    void slotChooseScientificConst4(int option);
-    void slotChooseScientificConst5(int option);
+    void slotConstantToDisplay(struct science_constant const &const_chosen);
+    void slotChooseScientificConst0(struct science_constant const &);
+    void slotChooseScientificConst1(struct science_constant const &);
+    void slotChooseScientificConst2(struct science_constant const &);
+    void slotChooseScientificConst3(struct science_constant const &);
+    void slotChooseScientificConst4(struct science_constant const &);
+    void slotChooseScientificConst5(struct science_constant const &);
+
+    void slotBitsetChanged(unsigned long long);
+    void slotUpdateBitset(const KNumber &);
 
 private:
-	bool inverse;
-	bool hyp_mode;
-	CALCAMNT memory_num;
-	CALCAMNT setvalue;
-
-	// angle modes for trigonometric values
-	enum {
-	  DegMode,
-	  RadMode,
-	  GradMode
-	} _angle_mode;
-
+    enum StatusField {
+        InvField = 0,
+        BaseField,
+        AngleField,
+        MemField
+    };
+    enum AngleMode {
+        DegMode = 0,
+        RadMode,
+        GradMode
+    };
+    enum BaseMode {
+        HexMode = 0,
+        DecMode,
+        OctMode,
+        BinMode
+    };
 
 private:
-    QWidget *mSmallPage;
-    QWidget *mLargePage;
-    QWidget *mNumericPage;
+    bool inverse;
+    bool hyp_mode;
+    KNumber memory_num;
+    KNumber setvalue;
 
-    DispLogic*	calc_display; // for historic reasons in "dlabel.h"
-    QRadioButton*	pbBaseChoose[4];
-    QPushButton*	pbAngleChoose;
-    QDict<KCalcButton>	pbStat;
-    QDict<KCalcButton>	pbTrig;
-    QDict<KCalcButton>	pbExp;
-    QDict<KCalcButton>	pbLogic;
-    KCalcConstButton*	pbConstant[10];
-    KCalcButton* 	pbAC;
-    KCalcButton* 	pbAND;
-    KCalcButton* 	pbClear;
-    KCalcButton* 	pbDivision;
-    KCalcButton* 	pbEE;
-    KCalcButton* 	pbEqual;
-    KCalcButton* 	pbFactorial;
-    KCalcButton* 	pbInv;
-    KCalcButton* 	pbMC;
-    KCalcButton* 	pbMinus;
-    KCalcButton* 	pbMod;
-    KCalcButton* 	pbMemPlusMinus;
-    KCalcButton* 	pbMemRecall;
-    KCalcButton*	pbMemStore;
-    KCalcButton* 	pbOR;
-    KCalcButton* 	pbParenClose;
-    KCalcButton* 	pbParenOpen;
-    KCalcButton* 	pbPercent;
-    KCalcButton* 	pbPeriod;
-    KCalcButton* 	pbPlus;
-    KCalcButton* 	pbPlusMinus;
-    KCalcButton* 	pbPower;
-    KCalcButton* 	pbReci;
-    KSquareButton* 	pbRoot;
-    KCalcButton* 	pbSquare;
-    KCalcButton* 	pbX;
-    KCalcButton* 	pbXOR;
+    int _angle_mode; // angle modes for trigonometric values
 
-    Constants * tmp_const; // this is the dialog for configuring const
-			   // buttons would like to remove this, but
-			   // don't know how
+    Constants*          constants; // this is the dialog for configuring const buttons
 	
-    QHButtonGroup*      BaseChooseGroup;
+    QButtonGroup*	AngleChooseGroup;
+    QButtonGroup* 	BaseChooseGroup;
     // NumButtonGroup: 0-9 = digits, 0xA-0xF = hex-keys
     QButtonGroup* 	NumButtonGroup;
-    // ConstButtonGroup C1-C6
-    QButtonGroup*	ConstButtonGroup;
+
+    QList<QAbstractButton*> logicButtons;
+    QList<QAbstractButton*> scientificButtons;
+    QList<QAbstractButton*> statButtons;
+    QList<QAbstractButton*> constButtons;
 
     KToggleAction *actionStatshow;
-    KToggleAction *actionTrigshow;
+    KToggleAction *actionScientificshow;
     KToggleAction *actionLogicshow;
-    KToggleAction *actionExpLogshow;
     KToggleAction *actionConstantsShow;
 
-    QPtrList<KCalcButton> mFunctionButtonList;
-    QPtrList<KCalcButton> mStatButtonList;
-    QPtrList<KCalcButton> mMemButtonList;
-    QPtrList<KCalcButton> mOperationButtonList;
-
-    int				mInternalSpacing;
+    QList<QAbstractButton*> mFunctionButtonList;
+    QList<QAbstractButton*> mStatButtonList;
+    QList<QAbstractButton*> mMemButtonList;
+    QList<QAbstractButton*> mOperationButtonList;
 
     CalcEngine core;
 };
