@@ -6,6 +6,7 @@
     Martin Bartlett's xfrmcalc
 
     portions:	Copyright (C) 2003-2006 Klaus Niederkrueger
+                                        kniederk@ulb.ac.be
 
     portions:	Copyright (C) 1996 Bernd Johannes Wuebben
                                    wuebben@math.cornell.edu
@@ -28,6 +29,9 @@
 
 */
 
+#include "kcalc_core.h"
+
+#include <config-kcalc.h>
 
 #if defined(_ISOC99_SOURCE)
 	#include <cassert>
@@ -46,8 +50,6 @@
 	#include <string.h>
 #endif
 
-#include <config.h>
-#include "kcalc_core.h"
 #include <stdlib.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -145,6 +147,37 @@ bool isoddint(const KNumber & input)
 	return ( (input / KNumber(2)).type() == KNumber::IntegerType);
 }
 
+  
+static KNumber ExecBinom(const KNumber & left_op, const KNumber & right_op) 
+{ 
+	if (left_op.type() != KNumber::IntegerType
+	    ||  right_op.type() != KNumber::IntegerType
+	    ||  right_op > left_op  ||  left_op < KNumber::Zero)
+		return KNumber::UndefinedNumber;
+
+	KNumber tmp_count = left_op;
+	KNumber tmp_result = KNumber::One;
+
+	// don't do recursive factorial,
+	// because large numbers lead to
+	// stack overflows
+	while (tmp_count > right_op)
+	{
+		tmp_result = tmp_count * tmp_result;
+		tmp_count -= KNumber::One;
+	}
+
+	tmp_count = left_op-right_op;
+	while (tmp_count > KNumber::One)
+	{
+		tmp_result = tmp_result / tmp_count;
+		tmp_count -= KNumber::One;
+	}
+
+
+	return tmp_result;
+} 
+
 static KNumber ExecPower(const KNumber & left_op, const KNumber & right_op)
 {
 	return left_op.power(right_op);
@@ -192,6 +225,7 @@ const struct operator_data CalcEngine::Operator[] = {
   { 6, ExecDivide,   ExecDivideP}, // FUNC_DIVIDE
   { 6, ExecMod,  NULL}, // FUNC_MOD
   { 6, ExecIntDiv, NULL}, // FUNC_INTDIV
+  { 7, ExecBinom, NULL},  // FUNC_BINOM 
   { 7, ExecPower,  NULL}, // FUNC_POWER
   { 7, ExecPwrRoot, NULL} // FUNC_PWR_ROOT
 };
@@ -206,7 +240,7 @@ CalcEngine::CalcEngine()
 	// handler to trap the errors that the code can/has not been
 	// written to trap.
 	//
-
+#ifndef Q_OS_WIN
 	struct sigaction fpe_trap;
 
 	sigemptyset(&fpe_trap.sa_mask);
@@ -215,7 +249,7 @@ CalcEngine::CalcEngine()
 	fpe_trap.sa_flags = SA_RESTART;
 #endif
 	sigaction(SIGFPE, &fpe_trap, NULL);
-
+#endif
 	_last_number = KNumber::Zero;
 	_error = false;
 }
@@ -458,7 +492,7 @@ void CalcEngine::Complement(KNumber input)
 		_last_number = KNumber("nan");
 		return;
 	}
-	_last_number = - input - KNumber::One; 
+	_last_number = - input - KNumber::One;
 }
 
 
