@@ -1,5 +1,6 @@
+// -*- indent-tabs-mode: nil -*-
 /*
-    $Id: kcalcdisplay.cpp 620021 2007-01-05 01:10:35Z kniederk $
+    $Id: kcalcdisplay.cpp 814914 2008-05-31 17:57:17Z brandybuck $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -23,55 +24,181 @@
 
 */
 
+#include "kcalcdisplay.h"
+
 #include <errno.h>
 #include <stdlib.h>
 #include <ctype.h>
 
-#include <qclipboard.h>
-#include <qpainter.h>
-#include <qregexp.h>
+#include <QClipboard>
+#include <QMouseEvent>
+#include <QPainter>
+#include <QStyle>
+#include <QTimer>
 
 #include <kglobal.h>
 #include <klocale.h>
-#include <knotifyclient.h>
+#include <knotification.h>
+#include "kcalc_core.h"
 #include "kcalc_settings.h"
-#include "kcalcdisplay.h"
 #include "kcalcdisplay.moc"
 
+const uint MARGIN = 2;
 
-KCalcDisplay::KCalcDisplay(QWidget *parent, const char *name)
-  :QLabel(parent,name), _beep(false), _groupdigits(false), _button(0), _lit(false),
-   _num_base(NB_DECIMAL), _precision(9),
-   _fixed_precision(-1), _display_amount(0),
-   selection_timer(new QTimer)
+KCalcDisplay::KCalcDisplay(QWidget *parent)
+    :QFrame(parent), _beep(false), _groupdigits(false), _button(0),
+     _lit(false), _num_base(NB_DECIMAL), _precision(9), _fixed_precision(-1),
+     _display_amount(0), _history_index(0), _selection_timer(new QTimer)
 {
-	setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
-	setAlignment(AlignRight | AlignVCenter);
-	setFocus();
-	setFocusPolicy(QWidget::StrongFocus);
-	setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed, false);
+    setAutoFillBackground(true);
+    setFocus();
+    setFocusPolicy(Qt::StrongFocus);
 
-	connect(this, SIGNAL(clicked()), this, SLOT(slotDisplaySelected()));
+    setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed));
 
-	connect(selection_timer, SIGNAL(timeout()),
-		this, SLOT(slotSelectionTimedOut()));
+    KNumber::setDefaultFloatOutput(true);
+    KNumber::setDefaultFractionalInput(true);
 
-	sendEvent(EventReset);
+    connect(this, SIGNAL(clicked()),
+            this, SLOT(slotDisplaySelected()));
+    connect(_selection_timer, SIGNAL(timeout()),
+            this, SLOT(slotSelectionTimedOut()));
+
+    sendEvent(EventReset);
 }
 
 KCalcDisplay::~KCalcDisplay()
 {
-	delete selection_timer;
+	delete _selection_timer;
+}
+
+void KCalcDisplay::changeSettings()
+{
+	QPalette pal = palette();
+
+	pal.setColor(QPalette::Text, KCalcSettings::foreColor());
+	pal.setColor(QPalette::WindowText, KCalcSettings::foreColor());
+	pal.setColor(QPalette::Window, KCalcSettings::backColor());
+
+	setPalette(pal);
+
+	setFont(KCalcSettings::font());
+
+	setPrecision(KCalcSettings::precision());
+
+	if(KCalcSettings::fixed() == false)
+		setFixedPrecision(-1);
+	else
+		setFixedPrecision(KCalcSettings::fixedPrecision());
+
+	setBeep(KCalcSettings::beep());
+	setGroupDigits(KCalcSettings::groupDigits());
+	updateDisplay();
+}
+
+void KCalcDisplay::updateFromCore(CalcEngine const &core,
+				 bool store_result_in_history)
+{
+	bool tmp_error;
+	KNumber const & output = core.lastOutput(tmp_error);
+	if(tmp_error) sendEvent(EventError);
+	if (setAmount(output)  &&  store_result_in_history  &&
+	    output != KNumber::Zero)
+	{
+	  // add this latest value to our history
+	  _history_list.insert(_history_list.begin(), output);
+	  _history_index = 0;
+	}
+}
+
+void KCalcDisplay::enterDigit(int data)
+{
+	char tmp;
+	switch(data)
+	{
+	case 0:
+	  tmp = '0';
+	  break;
+	case 1:
+	  tmp = '1';
+	  break;
+	case 2:
+	  tmp = '2';
+	  break;
+	case 3:
+	  tmp = '3';
+	  break;
+	case 4:
+	  tmp = '4';
+	  break;
+	case 5:
+	  tmp = '5';
+	  break;
+	case 6:
+	  tmp = '6';
+	  break;
+	case 7:
+	  tmp = '7';
+	  break;
+	case 8:
+	  tmp = '8';
+	  break;
+	case 9:
+	  tmp = '9';
+	  break;
+	case 0xA:
+	  tmp = 'A';
+	  break;
+	case 0xB:
+	  tmp = 'B';
+	  break;
+	case 0xC:
+	  tmp = 'C';
+	  break;
+	case 0xD:
+	  tmp = 'D';
+	  break;
+	case 0xE:
+	  tmp = 'E';
+	  break;
+	case 0xF:
+	  tmp = 'F';
+	  break;
+	default:
+	  tmp = '?';
+	  break;
+	}
+
+	newCharacter(tmp);
+}
+
+void KCalcDisplay::slotHistoryForward()
+{
+	if (_history_list.empty()) return;
+	if (_history_index <= 0) return;
+
+	_history_index --;
+	setAmount(_history_list[_history_index]);
+}
+
+void KCalcDisplay::slotHistoryBack()
+{
+	if ( _history_list.empty()) return;
+	if (_history_index >= _history_list.size()) return;
+
+	setAmount(_history_list[_history_index]);
+	_history_index ++;
 }
 
 bool KCalcDisplay::sendEvent(Event const event)
 {
 	switch(event)
 	{
+	case EventClear:
 	case EventReset:
 		_display_amount = 0;
 		_str_int = "0";
-		_str_int_exp = QString::null;
+		_str_int_exp.clear();
 
 		_eestate = false;
 		_period = false;
@@ -80,8 +207,6 @@ bool KCalcDisplay::sendEvent(Event const event)
 		updateDisplay();
 
 		return true;
-	case EventClear:
-		return sendEvent(EventReset);
 	case EventChangeSign:
 		return changeSign();
 	case EventError:
@@ -93,7 +218,6 @@ bool KCalcDisplay::sendEvent(Event const event)
 	}
 }
 
-
 void KCalcDisplay::slotCut(void)
 {
 	slotCopy();
@@ -104,7 +228,7 @@ void KCalcDisplay::slotCopy(void)
 {
 	QString txt;
 	if (_num_base != NB_DECIMAL)
-		txt = QLabel::text();
+		txt = _text;
 	else
 		txt = _display_amount.toQString();
 	if (_num_base == NB_HEX)
@@ -119,47 +243,48 @@ void KCalcDisplay::slotPaste(bool bClipboard)
 
 	if (tmp_str.isNull())
 	{
-		if (_beep)  KNotifyClient::beep();
+		if (_beep)  KNotification::beep();
 		return;
 	}
 
 	NumBase tmp_num_base = _num_base;
 
-	tmp_str = tmp_str.stripWhiteSpace();
+	tmp_str = tmp_str.trimmed();
 
-	if (tmp_str.startsWith("0x", false))
-	  tmp_num_base = NB_HEX;
+	if (tmp_str.startsWith("0x", Qt::CaseInsensitive)) tmp_num_base = NB_HEX;
 
 	if (tmp_num_base != NB_DECIMAL)
 	{
 		bool was_ok;
-		unsigned long long int tmp_result = tmp_str.toULongLong(& was_ok, tmp_num_base);
+		quint64 tmp_result = tmp_str.toULongLong(& was_ok, tmp_num_base);
 
 		if (!was_ok)
 		{
 			setAmount(KNumber::NotDefined);
-			if(_beep) KNotifyClient::beep();
+			if(_beep) KNotification::beep();
 			return ;
 		}
 	  
 		setAmount(KNumber(tmp_result));
 	} 
-	else // _num_base == NB_DECIMAL && ! tmp_str.startsWith("0x", false)
+	else // _num_base == NB_DECIMAL && ! 
+	     // tmp_str.startsWith("0x",Qt::CaseInsensitive)
 	{
 		setAmount(KNumber(tmp_str));
 		if (_beep  &&  _display_amount == KNumber::NotDefined)
-			KNotifyClient::beep();
+			KNotification::beep();
+
 	}
 }
 
 void KCalcDisplay::slotDisplaySelected(void)
 {
-	if(_button == LeftButton) {
+	if(_button == Qt::LeftButton) {
 		if(_lit) {
 			slotCopy();
-			selection_timer->start(100);
+			_selection_timer->start(100);
 		} else {
-			selection_timer->stop();
+			_selection_timer->stop();
 		}
 
 		invertColors();
@@ -172,25 +297,26 @@ void KCalcDisplay::slotSelectionTimedOut(void)
 {
 	_lit = false;
 	invertColors();
-	selection_timer->stop();
+	_selection_timer->stop();
 }
 
 void KCalcDisplay::invertColors()
 {
-	QColor tmp_col(paletteBackgroundColor());
-	setPaletteBackgroundColor(paletteForegroundColor());
-	setPaletteForegroundColor(tmp_col);
+	QPalette tmp_palette = palette();
+	tmp_palette.setColor(QPalette::Window,
+			palette().color(QPalette::WindowText));
+	tmp_palette.setColor(QPalette::WindowText,
+			palette().color(QPalette::Background));
+	setPalette(tmp_palette);
 }
 
-
-
 void KCalcDisplay::mousePressEvent(QMouseEvent *e)
 {
-	if(e->button() == LeftButton) {
+	if(e->button() == Qt::LeftButton) {
 		_lit = !_lit;
-		_button = LeftButton;
+		_button = Qt::LeftButton;
 	} else {
-		_button = MidButton;
+		_button = Qt::MidButton;
 	}
 	
 	emit clicked();
@@ -224,23 +350,22 @@ KNumber const & KCalcDisplay::getAmount(void) const
 	return _display_amount;
 }
 
-
 bool KCalcDisplay::setAmount(KNumber const & new_amount)
 {
 	QString display_str;
 
 	_str_int = "0";
-	_str_int_exp = QString::null;
+	_str_int_exp.clear();
 	_period = false;
 	_neg_sign = false;
 	_eestate = false;
 
-	if (_num_base != NB_DECIMAL  && new_amount.type() != KNumber::SpecialType)
+	if (_num_base != NB_DECIMAL  &&  new_amount.type() != KNumber::SpecialType)
 	{
 		_display_amount = new_amount.integerPart();
-		unsigned long long int tmp_workaround = static_cast<unsigned long long int>(_display_amount);
+		quint64 tmp_workaround = static_cast<quint64>(_display_amount);
 
-		display_str = QString::number(tmp_workaround, _num_base).upper();
+		display_str = QString::number(tmp_workaround, _num_base).toUpper();
 	}
 	else // _num_base == NB_DECIMAL || new_amount.type() ==
 	     // KNumber::SpecialType
@@ -256,39 +381,36 @@ bool KCalcDisplay::setAmount(KNumber const & new_amount)
 #endif
 	}
 
-	setText(display_str);
+    setText(display_str);
+	emit changedAmount(_display_amount);
 	return true;
 	
 }
 
 void KCalcDisplay::setText(QString const &string)
 {
-	QString localizedString = string;
+    // note that "C" locale is being used internally
+    _text = string;
 
-	// If we aren't in decimal mode, we don't need to modify the string
-	if (_num_base == NB_DECIMAL  &&  _groupdigits)
-	  // when input ends with "." (because uncomplete), the
-	  // formatNumber-method does not work; fix by hand by
-	  // truncating, formatting and appending again
-	  if (string.endsWith(".")) {
-	    localizedString.truncate(localizedString.length() - 1);
-	    localizedString = KGlobal::locale()->formatNumber(localizedString, false, 0); // Note: rounding happened already above!
-	    localizedString.append(KGlobal::locale()->decimalSymbol());
-	  } else
-	    localizedString = KGlobal::locale()->formatNumber(string, false, 0); // Note: rounding happened already above!
+    // if we aren't in decimal mode, we don't need to modify the string
+    if (_num_base == NB_DECIMAL && _groupdigits)
+        // when input ends with "." (because incomplete), the
+        // formatNumber method does not work; fix by hand by
+        // truncating, formatting and appending again
+        if (string.endsWith('.')) {
+            _text.chop(1);
+            _text = KGlobal::locale()->formatNumber(_text, false, 0); // Note: rounding happened already above!
+            _text.append(KGlobal::locale()->decimalSymbol());
+        } else
+            _text = KGlobal::locale()->formatNumber(_text, false, 0); // Note: rounding happened already above!
 
-	QLabel::setText(localizedString);
-	emit changedText(localizedString);
+    update();
+    emit changedText(_text);
 }
 
 QString KCalcDisplay::text() const
 {
-	if (_num_base != NB_DECIMAL)
-		return QLabel::text();
-	QString display_str = _display_amount.toQString(KCalcSettings::precision());
-
-	return display_str;
-	//	return QCString().sprintf(PRINT_LONG_BIG, 40, _display_amount);
+    return _text;
 }
 
 /* change representation of display to new base (i.e. binary, decimal,
@@ -297,7 +419,7 @@ QString KCalcDisplay::text() const
    being set with "setAmount"). Return value is the new base. */
 int KCalcDisplay::setBase(NumBase new_base)
 {
-	CALCAMNT tmp_val = static_cast<unsigned long long int>(getAmount());
+	CALCAMNT tmp_val = static_cast<quint64>(getAmount());
 
 	switch(new_base)
 	{
@@ -320,12 +442,12 @@ int KCalcDisplay::setBase(NumBase new_base)
 		_num_base	= NB_DECIMAL;
 	}
 
-	setAmount(static_cast<unsigned long long int>(tmp_val));
+	setAmount(static_cast<quint64>(tmp_val));
 	
 	return _num_base;
 }
 
-void KCalcDisplay::setStatusText(uint i, const QString& text)
+void KCalcDisplay::setStatusText(int i, const QString& text)
 {
 	if (i < NUM_STATUS_TEXT)
 		_str_status[i] = text;
@@ -337,7 +459,7 @@ bool KCalcDisplay::updateDisplay(void)
 	// Put sign in front.
 	QString tmp_string;
 	if(_neg_sign == true)
-		tmp_string = "-" + _str_int;
+		tmp_string = '-' + _str_int;
 	else
 		tmp_string = _str_int;
 
@@ -346,7 +468,7 @@ bool KCalcDisplay::updateDisplay(void)
 	case NB_BINARY:
 		Q_ASSERT(_period == false  && _eestate == false);
 		setText(tmp_string);
-		_display_amount = static_cast<unsigned long long int>(STRTOUL(_str_int.latin1(), 0, 2));
+		_display_amount = static_cast<quint64>(STRTOUL(_str_int.toLatin1(), 0, 2));
 		if (_neg_sign)
 			_display_amount = -_display_amount;
 		//str_size = cvb(_str_int, boh_work, DSP_SIZE);
@@ -355,7 +477,7 @@ bool KCalcDisplay::updateDisplay(void)
 	case NB_OCTAL:
 		Q_ASSERT(_period == false  && _eestate == false);
 		setText(tmp_string);
-		_display_amount = static_cast<unsigned long long int>(STRTOUL(_str_int.latin1(), 0, 8));
+		_display_amount = static_cast<quint64>(STRTOUL(_str_int.toLatin1(), 0, 8));
 		if (_neg_sign)
 			_display_amount = -_display_amount;
 		break;
@@ -363,7 +485,7 @@ bool KCalcDisplay::updateDisplay(void)
 	case NB_HEX:
 		Q_ASSERT(_period == false  && _eestate == false);
 		setText(tmp_string);
-		_display_amount = static_cast<unsigned long long int>(STRTOUL(_str_int.latin1(), 0, 16));
+		_display_amount = static_cast<quint64>(STRTOUL(_str_int.toLatin1(), 0, 16));
 		if (_neg_sign)
 			_display_amount = -_display_amount;
 		break;
@@ -394,7 +516,7 @@ bool KCalcDisplay::updateDisplay(void)
 	default:
 	  return false;
 	}
-
+	emit changedAmount(_display_amount);
 	return true;
 }
 
@@ -408,7 +530,7 @@ void KCalcDisplay::newCharacter(char const new_char)
 		if (_num_base != NB_DECIMAL  ||
 		    _eestate == true)
 		{
-			if(_beep) KNotifyClient::beep();
+			if(_beep) KNotification::beep();
 			return;
 		}
 		_eestate = true;
@@ -421,7 +543,7 @@ void KCalcDisplay::newCharacter(char const new_char)
 		    _period == true  ||
 		    _eestate == true)
 		{
-			if(_beep) KNotifyClient::beep();
+			if(_beep) KNotification::beep();
 			return;
 		}
 		_period = true;
@@ -435,7 +557,7 @@ void KCalcDisplay::newCharacter(char const new_char)
 	case 'A':
 		if (_num_base == NB_DECIMAL)
 		{
-			if(_beep) KNotifyClient::beep();
+			if(_beep) KNotification::beep();
 			return;
 		}
 		// no break
@@ -443,7 +565,7 @@ void KCalcDisplay::newCharacter(char const new_char)
 	case '8':
 		if (_num_base == NB_OCTAL)
 		{
-			if(_beep) KNotifyClient::beep();
+			if(_beep) KNotification::beep();
 			return;
 		}
 		// no break
@@ -455,7 +577,7 @@ void KCalcDisplay::newCharacter(char const new_char)
 	case '2':
 		if (_num_base == NB_BINARY)
 		{
-			if(_beep) KNotifyClient::beep();
+			if(_beep) KNotification::beep();
 			return;
 		}
 		// no break
@@ -464,7 +586,7 @@ void KCalcDisplay::newCharacter(char const new_char)
 		break;
 
 	default:
-		if(_beep) KNotifyClient::beep();
+		if(_beep) KNotification::beep();
 		return;
 	}
 
@@ -472,11 +594,11 @@ void KCalcDisplay::newCharacter(char const new_char)
 	if (_eestate)
 	{
 	  // ignore ',' before 'e'. turn e.g. '123.e' into '123e'
-	  if (new_char == 'e'  && _str_int.endsWith( "." ))
-	    {
-			_str_int.truncate(_str_int.length() - 1);
-			_period = false;
-	    }
+	  if (new_char == 'e'  &&  _str_int.endsWith( '.' ))
+	  {
+		_str_int.chop(1);
+		_period = false;
+	  }
 
 	  // 'e' only starts ee_mode, leaves strings unchanged
 	  if (new_char != 'e'  &&
@@ -526,7 +648,7 @@ void KCalcDisplay::deleteLastDigit(void)
 			int length = _str_int_exp.length();
 			if(length > 1)
 			{
-				_str_int_exp.truncate(length-1);
+				_str_int_exp.chop(1);
 			}
 			else
 			{
@@ -541,7 +663,7 @@ void KCalcDisplay::deleteLastDigit(void)
 		{
 			if (_str_int[length-1] == '.')
 				_period = false;
-			_str_int.truncate(length-1);
+			_str_int.chop(1);
 		}
 		else
 		{
@@ -581,32 +703,41 @@ bool KCalcDisplay::changeSign(void)
 	return true;
 }
 
-void KCalcDisplay::drawContents(QPainter *p)
+void KCalcDisplay::paintEvent(QPaintEvent *)
 {
-	QLabel::drawContents(p);
+    QPainter painter(this);
+    drawFrame(&painter);
 
-	// draw the status texts using half of the normal
-	// font size but not smaller than 7pt
-	QFont f(font());
-	f.setPointSize(QMAX((f.pointSize() / 2), 7));
-	p->setFont(f);
-	QFontMetrics fm(f);
-	uint w = fm.width("_____");
-	uint h = fm.height();
+    // draw display text
+    QRect cr = contentsRect();
+    //cr.adjust(MARGIN, 0, -MARGIN, 0); // provide a margin
+    int align = QStyle::visualAlignment(layoutDirection(),
+                                        Qt::AlignRight | Qt::AlignVCenter);
+    painter.drawText(cr, align | Qt::TextSingleLine, _text);
 
-	for (uint i = 0; i < NUM_STATUS_TEXT; i++)
-	{
-		p->drawText(5 + i * w, h, _str_status[i]);
-	}
+    // draw the status texts using half of the normal
+    // font size but not smaller than 7pt
+    QFont fnt(font());
+    fnt.setPointSize(qMax((fnt.pointSize() / 2), 7));
+    painter.setFont(fnt);
+    QFontMetrics fm(fnt);
+    uint w = fm.width("_____");
+    uint h = fm.height();
+
+    for (int n = 0; n < NUM_STATUS_TEXT; n++) {
+        painter.drawText(5 + n * w, h, _str_status[n]);
+    }
 }
 
-// Return the QLabel's normal size hint vertically expanded
-// by half the font height to make room for the status texts
 QSize KCalcDisplay::sizeHint() const
 {
-	QFont f(font());
-	f.setPointSize(QMAX((f.pointSize() / 2), 7));
-	QFontMetrics fm(f);
-	return QLabel::sizeHint() + QSize(0, fm.height());
+    // basic size
+    QSize sz = fontMetrics().size(Qt::TextSingleLine, _text);
+
+    // expanded by half font height to make room for  the status texts
+    QFont fnt(font());
+    fnt.setPointSize(qMax((fnt.pointSize() / 2), 7));
+    QFontMetrics fm(fnt);
+    return sz + QSize(MARGIN*2, fm.height());
 }
 
