@@ -20,12 +20,14 @@
 #ifndef _KNUMBER_H
 #define _KNUMBER_H
 
-#include <kdelibs_export.h>
+#include <kdemacros.h>
 
 #include "knumber_priv.h"
 
 class QString;
 
+class _knumber;
+
 /**
   *
   * @short Class that provides arbitrary precision numbers
@@ -105,11 +107,9 @@ class KDE_EXPORT KNumber
    */
   enum ErrorType {UndefinedNumber, Infinity, MinusInfinity};
 
-  KNumber(signed int num = 0);
-  KNumber(unsigned int num);  
-  KNumber(signed long int num);
-  KNumber(unsigned long int num);
-  KNumber(unsigned long long int num);
+  KNumber(qint32 num = 0);
+  KNumber(quint32 num);  
+  KNumber(quint64 num);
 
   KNumber(double num);
 
@@ -117,10 +117,7 @@ class KDE_EXPORT KNumber
   
   KNumber(QString const & num);
   
-  ~KNumber()
-  {
-    delete _num;
-  }
+  virtual ~KNumber();
   
   KNumber const & operator=(KNumber const & num);
 
@@ -242,9 +239,9 @@ class KDE_EXPORT KNumber
   KNumber const operator>>(KNumber const & arg2) const;
 
   operator bool(void) const;
-  operator signed long int(void) const;
-  operator unsigned long int(void) const;
-  operator unsigned long long int(void) const;
+  operator qint32(void) const;
+  operator quint32(void) const;
+  operator quint64(void) const;
   operator double(void) const;
 
   bool const operator==(KNumber const & arg2) const
@@ -270,10 +267,7 @@ class KDE_EXPORT KNumber
 
 
   //KNumber const toFloat(void) const;
-  
-  
-  
-  
+
  private:
   void simplifyRational(void);
   int const compare(KNumber const & arg2) const;
