@@ -21,14 +21,16 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <config.h>
+#include "disklist.h"
 
 #include <math.h>
 #include <stdlib.h>
 #include <kdebug.h>
-#include <kapplication.h>
 
-#include "disklist.h"
+#include <QtCore/QTextStream>
+#include <kglobal.h>
+#include <kconfiggroup.h>
+#include <kdefakes.h>
 
 #define BLANK ' '
 #define DELIMITER '#'
@@ -37,29 +39,29 @@
 /***************************************************************************
   * constructor
 **/
-DiskList::DiskList(QObject *parent, const char *name)
-    : QObject(parent,name)
+DiskList::DiskList(QObject *parent)
+    : QObject(parent)
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 
    updatesDisabled = false;
 
    if (NO_FS_TYPE) {
-      kdDebug() << "df gives no FS_TYPE" << endl;
+      kDebug() << "df gives no FS_TYPE" ;
    }
 
    disks = new Disks;
-   disks->setAutoDelete(TRUE);
+   disks->setAutoDelete(true);
 
    // BackgroundProcesses ****************************************
-   dfProc = new KProcess(); Q_CHECK_PTR(dfProc);
-   connect( dfProc, SIGNAL(receivedStdout(KProcess *, char *, int) ),
-      this, SLOT (receivedDFStdErrOut(KProcess *, char *, int)) );
-   connect(dfProc,SIGNAL(processExited(KProcess *) ),
+   dfProc = new K3Process(); Q_CHECK_PTR(dfProc);
+   connect( dfProc, SIGNAL(receivedStdout(K3Process *, char *, int) ),
+      this, SLOT (receivedDFStdErrOut(K3Process *, char *, int)) );
+   connect(dfProc,SIGNAL(processExited(K3Process *) ),
       this, SLOT(dfDone() ) );
 
-   readingDFStdErrOut=FALSE;
-   config = kapp->config();
+   readingDFStdErrOut=false;
+   config = KGlobal::config();
    loadSettings();
 }
 
@@ -69,7 +71,7 @@ DiskList::DiskList(QObject *parent, const char *name)
 **/
 DiskList::~DiskList()
 {
-   kdDebug() << k_funcinfo << endl;
+   kDebug() ;
 }
 
 /**
@@ -85,27 +87,22 @@ void DiskList::setUpdatesDisabled(bool disable)
 **/
 void DiskList::applySettings()
 {
-  kdDebug() << k_funcinfo << endl;
+  kDebug() ;
 
-  QString oldgroup=config->group();
-  config->setGroup("DiskList");
+  KConfigGroup group(config, "DiskList");
   QString key;
   DiskEntry *disk;
   for (disk=disks->first();disk!=0;disk=disks->next()) {
-   key.sprintf("Mount%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
-                              ,SEPARATOR,disk->mountPoint().latin1());
-   config->writePathEntry(key,disk->mountCommand());
+   key = QLatin1String("Mount") + SEPARATOR + disk->deviceName() + SEPARATOR + disk->mountPoint();
+   group.writePathEntry(key,disk->mountCommand());
 
-   key.sprintf("Umount%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
-                              ,SEPARATOR,disk->mountPoint().latin1());
-   config->writePathEntry(key,disk->umountCommand());
+   key = QLatin1String("Umount") + SEPARATOR + disk->deviceName() + SEPARATOR + disk->mountPoint();
+   group.writePathEntry(key,disk->umountCommand());
 
-   key.sprintf("Icon%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
-                              ,SEPARATOR,disk->mountPoint().latin1());
-   config->writePathEntry(key,disk->realIconName());
+   key = QLatin1String("Icon") + SEPARATOR + disk->deviceName() + SEPARATOR + disk->mountPoint();
+   group.writePathEntry(key,disk->realIconName());
  }
- config->sync();
- config->setGroup(oldgroup);
+ group.sync();
 }
 
 
@@ -114,23 +111,20 @@ void DiskList::applySettings()
 **/
 void DiskList::loadSettings()
 {
-  kdDebug() << k_funcinfo << endl;
+  kDebug() ;
 
-  config->setGroup("DiskList");
+  const KConfigGroup group(config, "DiskList");
   QString key;
   DiskEntry *disk;
   for (disk=disks->first();disk!=0;disk=disks->next()) {
-    key.sprintf("Mount%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
-		,SEPARATOR,disk->mountPoint().latin1());
-    disk->setMountCommand(config->readPathEntry(key));
+    key = QLatin1String("Mount") + SEPARATOR + disk->deviceName() + SEPARATOR + disk->mountPoint();
+    disk->setMountCommand(group.readPathEntry(key, QString()));
 
-    key.sprintf("Umount%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
-		,SEPARATOR,disk->mountPoint().latin1());
-    disk->setUmountCommand(config->readPathEntry(key));
+    key = QLatin1String("Umount") + SEPARATOR + disk->deviceName() + SEPARATOR + disk->mountPoint();
+    disk->setUmountCommand(group.readPathEntry(key, QString()));
 
-    key.sprintf("Icon%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
-		,SEPARATOR,disk->mountPoint().latin1());
-    QString icon=config->readPathEntry(key);
+    key = QLatin1String("Icon") + SEPARATOR + disk->deviceName() + SEPARATOR + disk->mountPoint();
+    QString icon=group.readPathEntry(key, QString());
     if (!icon.isEmpty()) disk->setIconName(icon);
  }
 }
@@ -138,24 +132,24 @@ void DiskList::loadSettings()
 
 static QString expandEscapes(const QString& s) {
 QString rc;
-    for (unsigned int i = 0; i < s.length(); i++) {
+    for (int i = 0; i < s.length(); i++) {
         if (s[i] == '\\') {
             i++;
-            switch(s[i]) {
-            case '\\':  // backslash '\'
-               rc += '\\';
-               break;
-            case '0': // octal 0nn
-               rc += static_cast<char>(s.mid(i,3).toInt(0, 8));
-               i += 2;
-               break;
-            default:
+			QChar str=s.at(i);
+			if( str == '\\')
+					rc += '\\';
+			else if( str == '0')
+			{
+					rc += static_cast<char>(s.mid(i,3).toInt(0, 8));
+					i += 2;
+			}
+			else
+			{
                // give up and not process anything else because I'm too lazy
                // to implement other escapes
                rc += '\\';
                rc += s[i];
-               break;
-            }
+			}
         } else {
             rc += s[i];
         }
@@ -168,50 +162,50 @@ return rc;
 **/
 int DiskList::readFSTAB()
 {
-  kdDebug() << k_funcinfo << endl;
+  kDebug() ;
 
   if (readingDFStdErrOut || dfProc->isRunning()) return -1;
 
 QFile f(FSTAB);
-  if ( f.open(IO_ReadOnly) ) {
+  if ( f.open(QIODevice::ReadOnly) ) {
     QTextStream t (&f);
     QString s;
     DiskEntry *disk;
 
     //disks->clear(); // ############
 
-    while (! t.eof()) {
+    while (! t.atEnd()) {
       s=t.readLine();
-      s=s.simplifyWhiteSpace();
-      if ( (!s.isEmpty() ) && (s.find(DELIMITER)!=0) ) {
+      s=s.simplified();
+      if ( (!s.isEmpty() ) && (s.indexOf(DELIMITER)!=0) ) {
                // not empty or commented out by '#'
-	//	kdDebug() << "GOT: [" << s << "]" << endl;
+	//	kDebug() << "GOT: [" << s << "]" ;
 	disk = new DiskEntry();// Q_CHECK_PTR(disk);
-        disk->setMounted(FALSE);
-        disk->setDeviceName(expandEscapes(s.left(s.find(BLANK))));
-            s=s.remove(0,s.find(BLANK)+1 );
-	    //  kdDebug() << "    deviceName:    [" << disk->deviceName() << "]" << endl;
+        disk->setMounted(false);
+        disk->setDeviceName(expandEscapes(s.left(s.indexOf(BLANK))));
+            s=s.remove(0,s.indexOf(BLANK)+1 );
+	    //  kDebug() << "    deviceName:    [" << disk->deviceName() << "]" ;
 #ifdef _OS_SOLARIS_
             //device to fsck
-            s=s.remove(0,s.find(BLANK)+1 );
+            s=s.remove(0,s.indexOf(BLANK)+1 );
 #endif
-         disk->setMountPoint(expandEscapes(s.left(s.find(BLANK))));
-            s=s.remove(0,s.find(BLANK)+1 );
-	    //kdDebug() << "    MountPoint:    [" << disk->mountPoint() << "]" << endl;
-	    //kdDebug() << "    Icon:          [" << disk->iconName() << "]" << endl;
-         disk->setFsType(s.left(s.find(BLANK)) );
-            s=s.remove(0,s.find(BLANK)+1 );
-	    //kdDebug() << "    FS-Type:       [" << disk->fsType() << "]" << endl;
-         disk->setMountOptions(s.left(s.find(BLANK)) );
-            s=s.remove(0,s.find(BLANK)+1 );
-	    //kdDebug() << "    Mount-Options: [" << disk->mountOptions() << "]" << endl;
+         disk->setMountPoint(expandEscapes(s.left(s.indexOf(BLANK))));
+            s=s.remove(0,s.indexOf(BLANK)+1 );
+	    //kDebug() << "    MountPoint:    [" << disk->mountPoint() << "]" ;
+	    //kDebug() << "    Icon:          [" << disk->iconName() << "]" ;
+         disk->setFsType(s.left(s.indexOf(BLANK)) );
+            s=s.remove(0,s.indexOf(BLANK)+1 );
+	    //kDebug() << "    FS-Type:       [" << disk->fsType() << "]" ;
+         disk->setMountOptions(s.left(s.indexOf(BLANK)) );
+            s=s.remove(0,s.indexOf(BLANK)+1 );
+	    //kDebug() << "    Mount-Options: [" << disk->mountOptions() << "]" ;
          if ( (disk->deviceName() != "none")
 	      && (disk->fsType() != "swap")
 	      && (disk->fsType() != "sysfs")
 	      && (disk->mountPoint() != "/dev/swap")
 	      && (disk->mountPoint() != "/dev/pts")
 	      && (disk->mountPoint() != "/dev/shm")
-	      && (disk->mountPoint().find("/proc") == -1 ) )
+	      && (!disk->mountPoint().contains("/proc") ) )
 	   replaceDeviceEntry(disk);
          else
            delete disk;
@@ -223,7 +217,7 @@ QFile f(FSTAB);
 
   loadSettings(); //to get the mountCommands
 
-  //  kdDebug() << "DiskList::readFSTAB DONE" << endl;
+  //  kDebug() << "DiskList::readFSTAB DONE" ;
   return 1;
 }
 
@@ -231,9 +225,9 @@ QFile f(FSTAB);
 /***************************************************************************
   * is called, when the df-command writes on StdOut or StdErr
 **/
-void DiskList::receivedDFStdErrOut(KProcess *, char *data, int len )
+void DiskList::receivedDFStdErrOut(K3Process *, char *data, int len )
 {
-  kdDebug() << k_funcinfo << endl;
+  kDebug() ;
 
 
   /* ATTENTION: StdERR no longer connected to this...
@@ -241,7 +235,7 @@ void DiskList::receivedDFStdErrOut(KProcess *, char *data, int len )
    * df: /home_tu1/ijzerman/floppy: Stale NFS file handle
    * but this shouldn't cause a real problem
    */
-   
+
 
   QString tmp = QString::fromLatin1(data, len);
   dfStringErrOut.append(tmp);
@@ -252,19 +246,21 @@ void DiskList::receivedDFStdErrOut(KProcess *, char *data, int len )
 **/
 int DiskList::readDF()
 {
-  kdDebug() << k_funcinfo << endl;
+  kDebug() ;
 
   if (readingDFStdErrOut || dfProc->isRunning()) return -1;
-  setenv("LANG", "en_US", 1);
-  setenv("LC_ALL", "en_US", 1);
-  setenv("LC_MESSAGES", "en_US", 1);
-  setenv("LC_TYPE", "en_US", 1);
-  setenv("LANGUAGE", "en_US", 1);
+  
   dfStringErrOut=""; // yet no data received
   dfProc->clearArguments();
-  (*dfProc) << "env" << "LC_ALL=POSIX" << DF_COMMAND << DF_ARGS;
-  if (!dfProc->start( KProcess::NotifyOnExit, KProcess::AllOutput ))
-    qFatal(i18n("could not execute [%s]").local8Bit().data(), DF_COMMAND);
+  dfProc->setEnvironment("LANG", "en_US");
+  dfProc->setEnvironment("LC_ALL", "en_US");
+  dfProc->setEnvironment("LC_MESSAGES", "en_US");
+  dfProc->setEnvironment("LC_TYPE", "en_US");
+  dfProc->setEnvironment("LANGUAGE", "en_US");
+  dfProc->setEnvironment("LC_ALL", "POSIX");
+  (*dfProc) << DF_COMMAND << DF_ARGS;
+  if (!dfProc->start( K3Process::NotifyOnExit, K3Process::AllOutput ))
+    qFatal("%s", qPrintable(i18n("could not execute [%1]", QLatin1String(DF_COMMAND))));
   return 1;
 }
 
@@ -274,70 +270,70 @@ int DiskList::readDF()
 **/
 void DiskList::dfDone()
 {
-  kdDebug() << k_funcinfo << endl;
+  kDebug() ;
 
   if (updatesDisabled)
       return; //Don't touch the data for now..
-	  
-  readingDFStdErrOut=TRUE;
-  for ( DiskEntry *disk=disks->first(); disk != 0; disk=disks->next() )
-    disk->setMounted(FALSE);  // set all devs unmounted
 
-  QTextStream t (dfStringErrOut, IO_ReadOnly);
+  readingDFStdErrOut=true;
+  for ( DiskEntry *disk=disks->first(); disk != 0; disk=disks->next() )
+    disk->setMounted(false);  // set all devs unmounted
+
+  QTextStream t (&dfStringErrOut, QIODevice::ReadOnly);
   QString s=t.readLine();
   if ( ( s.isEmpty() ) || ( s.left(10) != "Filesystem" ) )
-    qFatal("Error running df command... got [%s]",s.latin1());
+    qFatal("Error running df command... got [%s]",qPrintable(s));
   while ( !t.atEnd() ) {
     QString u,v;
     DiskEntry *disk;
     s=t.readLine();
-    s=s.simplifyWhiteSpace();
+    s=s.simplified();
     if ( !s.isEmpty() ) {
       disk = new DiskEntry(); Q_CHECK_PTR(disk);
 
-      if (s.find(BLANK)<0)      // devicename was too long, rest in next line
-	if ( !t.eof() ) {       // just appends the next line
+      if (!s.contains(BLANK))      // devicename was too long, rest in next line
+	if ( !t.atEnd() ) {       // just appends the next line
             v=t.readLine();
-            s=s.append(v.latin1() );
-            s=s.simplifyWhiteSpace();
-	    //kdDebug() << "SPECIAL GOT: [" << s << "]" << endl;
+            s=s.append(v );
+            s=s.simplified();
+	    //kDebug() << "SPECIAL GOT: [" << s << "]" ;
 	 }//if silly linefeed
 
-      //kdDebug() << "EFFECTIVELY GOT " << s.length() << " chars: [" << s << "]" << endl;
+      //kDebug() << "EFFECTIVELY GOT " << s.length() << " chars: [" << s << "]" ;
 
-      disk->setDeviceName(s.left(s.find(BLANK)) );
-      s=s.remove(0,s.find(BLANK)+1 );
-      //kdDebug() << "    DeviceName:    [" << disk->deviceName() << "]" << endl;
+      disk->setDeviceName(s.left(s.indexOf(BLANK)) );
+      s=s.remove(0,s.indexOf(BLANK)+1 );
+      //kDebug() << "    DeviceName:    [" << disk->deviceName() << "]" ;
 
       if (NO_FS_TYPE) {
-	//kdDebug() << "THERE IS NO FS_TYPE_FIELD!" << endl;
+	//kDebug() << "THERE IS NO FS_TYPE_FIELD!" ;
          disk->setFsType("?");
       } else {
-         disk->setFsType(s.left(s.find(BLANK)) );
-         s=s.remove(0,s.find(BLANK)+1 );
+         disk->setFsType(s.left(s.indexOf(BLANK)) );
+         s=s.remove(0,s.indexOf(BLANK)+1 );
       };
-      //kdDebug() << "    FS-Type:       [" << disk->fsType() << "]" << endl;
-      //kdDebug() << "    Icon:          [" << disk->iconName() << "]" << endl;
+      //kDebug() << "    FS-Type:       [" << disk->fsType() << "]" ;
+      //kDebug() << "    Icon:          [" << disk->iconName() << "]" ;
 
-      u=s.left(s.find(BLANK));
+      u=s.left(s.indexOf(BLANK));
       disk->setKBSize(u.toInt() );
-      s=s.remove(0,s.find(BLANK)+1 );
-      //kdDebug() << "    Size:       [" << disk->kBSize() << "]" << endl;
+      s=s.remove(0,s.indexOf(BLANK)+1 );
+      //kDebug() << "    Size:       [" << disk->kBSize() << "]" ;
 
-      u=s.left(s.find(BLANK));
+      u=s.left(s.indexOf(BLANK));
       disk->setKBUsed(u.toInt() );
-      s=s.remove(0,s.find(BLANK)+1 );
-      //kdDebug() << "    Used:       [" << disk->kBUsed() << "]" << endl;
+      s=s.remove(0,s.indexOf(BLANK)+1 );
+      //kDebug() << "    Used:       [" << disk->kBUsed() << "]" ;
 
-      u=s.left(s.find(BLANK));
+      u=s.left(s.indexOf(BLANK));
       disk->setKBAvail(u.toInt() );
-      s=s.remove(0,s.find(BLANK)+1 );
-      //kdDebug() << "    Avail:       [" << disk->kBAvail() << "]" << endl;
+      s=s.remove(0,s.indexOf(BLANK)+1 );
+      //kDebug() << "    Avail:       [" << disk->kBAvail() << "]" ;
 
 
-      s=s.remove(0,s.find(BLANK)+1 );  // delete the capacity 94%
+      s=s.remove(0,s.indexOf(BLANK)+1 );  // delete the capacity 94%
       disk->setMountPoint(s);
-      //kdDebug() << "    MountPoint:       [" << disk->mountPoint() << "]" << endl;
+      //kDebug() << "    MountPoint:       [" << disk->mountPoint() << "]" ;
 
       if ( (disk->kBSize() > 0)
 	   && (disk->deviceName() != "none")
@@ -346,8 +342,8 @@ void DiskList::dfDone()
 	   && (disk->mountPoint() != "/dev/swap")
 	   && (disk->mountPoint() != "/dev/pts")
 	   && (disk->mountPoint() != "/dev/shm")
-	   && (disk->mountPoint().find("/proc") == -1 ) ) {
-        disk->setMounted(TRUE);    // its now mounted (df lists only mounted)
+	   && (!disk->mountPoint().contains("/proc") ) ) {
+        disk->setMounted(true);    // its now mounted (df lists only mounted)
 	replaceDeviceEntry(disk);
       } else
 	delete disk;
@@ -355,7 +351,7 @@ void DiskList::dfDone()
     }//if not header
   }//while further lines available
 
-  readingDFStdErrOut=FALSE;
+  readingDFStdErrOut=false;
   loadSettings(); //to get the mountCommands
   emit readDFDone();
 }
@@ -363,13 +359,13 @@ void DiskList::dfDone()
 
 void DiskList::deleteAllMountedAt(const QString &mountpoint)
 {
-  kdDebug() << k_funcinfo << endl;
+  kDebug() ;
 
 
     for ( DiskEntry *item  = disks->first(); item;  )
     {
         if (item->mountPoint() == mountpoint ) {
-            kdDebug() << "delete " << item->deviceName() << endl;
+            kDebug() << "delete " << item->deviceName() ;
             disks->remove(item);
             item = disks->current();
         } else
@@ -382,7 +378,7 @@ void DiskList::deleteAllMountedAt(const QString &mountpoint)
 **/
 void DiskList::replaceDeviceEntry(DiskEntry *disk)
 {
-  //kdDebug() << k_funcinfo << disk->deviceRealName() << " " << disk->realMountPoint() << endl;
+  //kDebug() << disk->deviceRealName() << " " << disk->realMountPoint() ;
 
   //
   // The 'disks' may already already contain the 'disk'. If it do
@@ -426,13 +422,13 @@ void DiskList::replaceDeviceEntry(DiskEntry *disk)
 	// eg. /cache/cache/.cfs_mnt_points/srv:_home_jesus
 	//                                      ^    ^
         QString odiskName = olddisk->deviceName();
-        int ci=odiskName.find(':'); // goto host-column
-        while ((ci =odiskName.find('/',ci)) > 0) {
+        int ci=odiskName.indexOf(':'); // goto host-column
+        while ((ci =odiskName.indexOf('/',ci)) > 0) {
            odiskName.replace(ci,1,"_");
         }//while
         // check if there is something that is exactly the tail
 	// eg. [srv:/tmp3] is exact tail of [/cache/.cfs_mnt_points/srv:_tmp3]
-        if ( ( (p=disk->deviceName().findRev(odiskName
+        if ( ( (p=disk->deviceName().lastIndexOf(odiskName
 	            ,disk->deviceName().length()) )
                 != -1)
 	      && (p + odiskName.length()
@@ -457,8 +453,8 @@ void DiskList::replaceDeviceEntry(DiskEntry *disk)
 
   if (pos != -1) {  // replace
       DiskEntry * olddisk = disks->at(pos);
-      if ( (-1!=olddisk->mountOptions().find("user")) &&
-           (-1==disk->mountOptions().find("user")) ) {
+      if ( (olddisk->mountOptions().contains("user")) &&
+           ( disk->mountOptions().contains("user")) ) {
           // add "user" option to new diskEntry
           QString s=disk->mountOptions();
           if (s.length()>0) s.append(",");
@@ -470,7 +466,9 @@ void DiskList::replaceDeviceEntry(DiskEntry *disk)
 
       // Same device name, but maybe one is a symlink and the other is its target
       // Keep the shorter one then, /dev/hda1 looks better than /dev/ide/host0/bus0/target0/lun0/part1
-      if ( disk->deviceName().length() > olddisk->deviceName().length() )
+      // but redefine "shorter" to be the number of slashes in the path as a count on characters
+      // breaks legitimate symlinks created by udev
+      if ( disk->deviceName().count( '/' ) > olddisk->deviceName().count( '/' ) )
           disk->setDeviceName(olddisk->deviceName());
 
       //FStab after an older DF ... needed for critFull
@@ -484,7 +482,7 @@ void DiskList::replaceDeviceEntry(DiskEntry *disk)
           if ( (olddisk->percentFull() != -1) &&
                (olddisk->percentFull() <  FULL_PERCENT) &&
                   (disk->percentFull() >= FULL_PERCENT) ) {
-	    kdDebug() << "Device " << disk->deviceName()
+	    kDebug() << "Device " << disk->deviceName()
 		      << " is critFull! " << olddisk->percentFull()
 		      << "--" << disk->percentFull() << endl;
             emit criticallyFull(disk);
