@@ -28,14 +28,14 @@
 #include "mntconfig.h"
 
 #include <kcmodule.h>
-#include <qtabwidget.h>
+#include <QtGui/QTabWidget>
 
 class KDiskFreeWidget : public KCModule
 {
   Q_OBJECT
   
   public:
-    KDiskFreeWidget( QWidget *parent=0, const char *name=0 );
+    explicit KDiskFreeWidget( const KComponentData &inst, QWidget *parent = 0  );
     ~KDiskFreeWidget();
 
     QString quickHelp() const;
