@@ -28,24 +28,23 @@
 // Usage bars should work again.
 //
 
+#include "kdfwidget.h"
 #include <stdlib.h>
 
-#include <qheader.h>
-#include <qtimer.h>
-#include <qlayout.h>
-#include <qpainter.h>
+#include <QtCore/QTimer>
+#include <QtGui/QLayout>
+#include <QtGui/QPainter>
+#include <QtCore/QAbstractEventDispatcher>
 
 #include <kapplication.h>
-#include <kcmenumngr.h>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
-#include <kprocess.h>
-
+#include <kmenu.h>
+#include <ktoolinvocation.h>
+#include <kglobal.h>
+#include <kshell.h>
 #include "listview.h"
-#include "kdfwidget.h"
 #include "optiondialog.h"
 
-
 #define BAR_COLUMN   7
 #define FULL_PERCENT 95.0
 
@@ -56,11 +55,11 @@ static bool GUI;
 
 /**************************************************************/
 
-CListViewItem::CListViewItem( CListView * parent, QListViewItem * after )
-  :QListViewItem( parent, after )
+CListViewItem::CListViewItem( CListView * parent, Q3ListViewItem * after )
+  :Q3ListViewItem( parent, after )
 {}
 
-int CListViewItem::compare ( QListViewItem *i, int column, bool ) const
+int CListViewItem::compare ( Q3ListViewItem *i, int column, bool ) const
 {
   QString tmp;
 
@@ -92,8 +91,8 @@ void CListViewItem::setKeys (int kb_size, int kb_avail, float percent_full)
 
 /**************************************************************/
 
-KDFWidget::KDFWidget( QWidget *parent, const char *name, bool init )
-  : QWidget(parent, name), mOptionDialog(0), mPopup(0), mTimer(0)
+KDFWidget::KDFWidget( QWidget *parent, bool init )
+  : QWidget(parent), mOptionDialog(0), mPopup(0), mTimer(0)
 {
   connect(&mDiskList , SIGNAL(readDFDone() ),
            this, SLOT (updateDFDone()) );
@@ -101,20 +100,22 @@ KDFWidget::KDFWidget( QWidget *parent, const char *name, bool init )
            this, SLOT (criticallyFull(DiskEntry*)) );
 
   mTabProp.resize(8);
-  mTabProp[0] = new CTabEntry( "Icon", i18n("Icon"), true, 32);
-  mTabProp[1] = new CTabEntry( "Device", i18n("Device"), true, 80);
-  mTabProp[2] = new CTabEntry( "Type", i18n("Type"), true, 50);
-  mTabProp[3] = new CTabEntry( "Size", i18n("Size"), true, 72);
-  mTabProp[4] = new CTabEntry( "MountPoint", i18n("Mount Point"), true, 90 );
-  mTabProp[5] = new CTabEntry( "Free", i18n("Free"), true, 55);
+  mTabProp[0] = new CTabEntry( "Icon", i18nc("Storage device icon", "Icon"), true, 32);
+  mTabProp[1] = new CTabEntry( "Device", i18nc("Device of the storage", "Device"), true, 80);
+  mTabProp[2] = new CTabEntry( "Type", i18nc("Filesystem on storage", "Type"), true, 50);
+  mTabProp[3] = new CTabEntry( "Size", i18nc("Total size of the storage", "Size"), true, 72);
+  mTabProp[4] = new CTabEntry( "MountPoint", i18nc("Mount point of storage", "Mount Point"), true, 90 );
+  mTabProp[5] = new CTabEntry( "Free", i18nc("Free space in storage", "Free"), true, 55);
   // xgettext:no-c-format
-  mTabProp[6] = new CTabEntry( "Full%", i18n("Full %"), true, 70);
-  mTabProp[7] = new CTabEntry( "UsageBar", i18n("Usage"), true, 100);
+  mTabProp[6] = new CTabEntry( "Full%", i18nc("Used storage space in %", "Full %"), true, 70);
+  mTabProp[7] = new CTabEntry( "UsageBar", i18nc("Usage graphical bar", "Usage"), true, 100);
 
   GUI = !init;
   if( GUI )
   {
-    QVBoxLayout *topLayout = new QVBoxLayout( this, 0, 0 );
+    QVBoxLayout *topLayout = new QVBoxLayout( this );
+    topLayout->setSpacing( 0 );
+    topLayout->setMargin( 0 );
     mList = new CListView( this, "list" );
     topLayout->addWidget( mList );
 
@@ -122,16 +123,13 @@ KDFWidget::KDFWidget( QWidget *parent, const char *name, bool init )
     mList->setFrameStyle( QFrame::WinPanel + QFrame::Sunken );
     mList->setShowSortIndicator(true);
     connect( mList,
-      SIGNAL( rightButtonPressed( QListViewItem *, const QPoint &, int )),
-      this, SLOT( rightButtonPressed( QListViewItem *, const QPoint &, int )));
-    connect( mList,
-      SIGNAL( rightButtonClicked( QListViewItem *, const QPoint &, int )),
-      this, SLOT( rightButtonClicked( QListViewItem *, const QPoint &, int )));
-    connect( mList->header(), SIGNAL(sizeChange(int, int, int)),
-      this, SLOT(columnSizeChanged(int, int, int)) );
+      SIGNAL( rightButtonPressed( Q3ListViewItem *, const QPoint &, int )),
+      this, SLOT( rightButtonPressed( Q3ListViewItem *, const QPoint &, int )));
+//    connect( mList->header(), SIGNAL(sizeChange(int, int, int)), // no need to connect header
+//      this, SLOT(columnSizeChanged(int, int, int)) );            // as not going to be displayed
     makeColumns();
 
-    mIsTopLevel = QString(parent->className()) == "KDFTopLevel" ? true : false;
+    mIsTopLevel = QString(parent->metaObject()->className()) == "KDFTopLevel" ? true : false;
   }
 
   loadSettings();
@@ -160,15 +158,20 @@ void KDFWidget::makeColumns( void )
   // I only need as many iterations as there are header items but who knows
   // what a new Qt can do!
   //
-  for( i=1000; mList->header()->count() > 0 && i>0; i-- )
-  {
-    mList->header()->removeLabel( 0 );
-    mList->header()->update();
-  }
-  for( i=0; i<mTabProp.size(); mList->removeColumn(i++) );
-  mList->clear();
 
-  for( i=0; i<mTabProp.size(); i++ )
+// there is no reason to first do headers, but then remove them before displaying
+
+//  for( i=1000; mList->header()->count() > 0 && i>0; i-- )
+//  {
+//    mList->header()->removeLabel( 0 );
+//    mList->header()->update();
+//  }
+//  for( int i=0; i<mTabProp.size(); mList->removeColumn(i++) );
+//  mList->clear();
+
+  int columns = mList->columns();
+  for (int i=0; i<columns; ++i) mList->removeColumn(0);
+  for( int i=0; i<mTabProp.size(); i++ )
   {
     CTabEntry &e = *mTabProp[i];
     if( e.mVisible == true )
@@ -202,12 +205,12 @@ void KDFWidget::settingsChanged( void )
 **/
 void KDFWidget::applySettings( void )
 {
-  KConfig &config = *kapp->config();
+  KConfig m_config;
+  KConfigGroup config( &m_config, "KDiskFree" );
 
-  config.setGroup("KDiskFree");
   if( GUI )
   {
-    for( uint i=0; i<mTabProp.size(); i++ )
+    for( int i=0; i<mTabProp.size(); i++ )
     {
       CTabEntry &e = *mTabProp[i];
       if( e.mVisible == true )
@@ -231,21 +234,20 @@ void KDFWidget::loadSettings( void )
 
   if(GUI)
   {
-    KConfig &config = *kapp->config();
-    config.setGroup("KDiskFree");
-    for( uint i=0; i<mTabProp.size(); i++ )
+    KConfigGroup config(KGlobal::config(), "KDiskFree");
+    for( int i=0; i<mTabProp.size(); i++ )
     {
       CTabEntry &e = *mTabProp[i];
-      e.mWidth = config.readNumEntry( e.mRes, e.mWidth );
+      e.mWidth = config.readEntry( e.mRes, e.mWidth );
     }
     if (mTabProp[usageCol]->mWidth > 16)
       mTabProp[usageCol]->mWidth -= 16;
 
-    config.setGroup("KDFConfig");
-    for( uint i=0; i<mTabProp.size(); i++ )
+    config.changeGroup("KDFConfig");
+    for( int i=0; i<mTabProp.size(); i++ )
     {
       CTabEntry &e = *mTabProp[i];
-      e.mVisible = config.readBoolEntry( e.mRes, e.mVisible );
+      e.mVisible = config.readEntry( e.mRes, e.mVisible );
     }
 
     makeColumns();
@@ -264,7 +266,7 @@ void KDFWidget::settingsBtnClicked( void )
   {
     if( mOptionDialog == 0 )
     {
-      mOptionDialog = new COptionDialog( this, "options", false );
+      mOptionDialog = new COptionDialog( this );
       if( mOptionDialog == 0 ) { return; }
       connect( mOptionDialog, SIGNAL(valueChanged()),
 	       this, SLOT(settingsChanged()) );
@@ -283,8 +285,8 @@ void KDFWidget::setUpdateFrequency( int frequency )
   // Kill current timer and restart it if the frequency is
   // larger than zero.
   //
-  killTimers();
-  if( frequency > 0 )
+	QAbstractEventDispatcher::instance()->unregisterTimers(this);
+   if( frequency > 0 )
   {
     startTimer( frequency * 1000 );
   }
@@ -309,7 +311,7 @@ void KDFWidget::updateDF( void )
   //
   if( mPopup == 0 )
   {
-    readingDF = TRUE;
+    readingDF = true;
     mDiskList.readFSTAB();
     mDiskList.readDF();
   }
@@ -343,7 +345,7 @@ void KDFWidget::updateDFDone( void ){
 
     int k=0;
     item = new CListViewItem( mList, item );
-    bool root = disk->mountOptions().find("user",0,false)==-1 ? true : false;
+    bool root = disk->mountOptions().contains("user", Qt::CaseInsensitive);
     item->setPixmap( k++, mList->icon( disk->iconName(), root ) );
     item->setText( k++, disk->deviceName() );
     item->setText( k++, disk->fsType() );
@@ -376,9 +378,9 @@ void KDFWidget::criticallyFull( DiskEntry *disk )
 {
   if( mStd.popupIfFull() == true )
   {
-    QString msg = i18n("Device [%1] on [%2] is getting critically full!").
-      arg(disk->deviceName()).arg(disk->mountPoint());
-    KMessageBox::sorry( this, msg, i18n("Warning"));
+    QString msg = i18n("Device [%1] on [%2] is critically full.",
+      disk->deviceName(), disk->mountPoint());
+    KMessageBox::sorry( this, msg, i18nc("Warning device getting critically full", "Warning"));
   }
 }
 
@@ -386,7 +388,7 @@ void KDFWidget::criticallyFull( DiskEntry *disk )
 /**************************************************************************
   * find correct disk related to list item
 **/
-DiskEntry *KDFWidget::selectedDisk( QListViewItem *item )
+DiskEntry *KDFWidget::selectedDisk( Q3ListViewItem *item )
 {
   if( item == 0 )
   {
@@ -426,28 +428,15 @@ DiskEntry *KDFWidget::selectedDisk( QListViewItem *item )
   //  return(0);
 }
 
-void KDFWidget::rightButtonPressed( QListViewItem *item, const QPoint &p, int )
+void KDFWidget::rightButtonPressed( Q3ListViewItem *item, const QPoint &p, int )
 {
-  if( KContextMenuManager::showOnButtonPress() == true )
-  {
-    popupMenu( item, p );
-  }
+  popupMenu( item, p );
 }
 
-
-void KDFWidget::rightButtonClicked( QListViewItem *item, const QPoint &p, int )
-{
-  if( KContextMenuManager::showOnButtonPress() == false )
-  {
-    popupMenu( item, p );
-  }
-}
-
-
 /**************************************************************************
   * pops up and asks for mount/umount right-clicked device
 **/
-void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
+void KDFWidget::popupMenu( Q3ListViewItem *item, const QPoint &p )
 {
   if (mPopup) //The user may even be able to popup another menu while this open is active...
        return;
@@ -457,34 +446,34 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
   // visible. Reason: The 'disk' may no longer be valid.
   //
 
-  mDiskList.setUpdatesDisabled(true);  
+  mDiskList.setUpdatesDisabled(true);
   DiskEntry *disk = selectedDisk( item );
   if( disk == 0 )
   {
     return;
   }
 
-  mPopup = new KPopupMenu( 0 );
-  mPopup->insertTitle( disk->mountPoint() );
-  mPopup->insertItem( i18n("Mount Device"), 0 );
-  mPopup->insertItem( i18n("Unmount Device"), 1 );
-  mPopup->insertSeparator();
-  mPopup->insertItem( i18n("Open in File Manager"), 2 );
-  mPopup->setItemEnabled( 0, disk->mounted() ? false : true );
-  mPopup->setItemEnabled( 1, disk->mounted() );
-  mPopup->setItemEnabled( 2, disk->mounted() );  
-  int position = mPopup->exec( p );  
-  
+  mPopup = new KMenu( 0 );
+  mPopup->addTitle( disk->mountPoint() );
+  QAction *mountPointAction = mPopup->addAction( i18n("Mount Device") );
+  QAction *umountPointAction = mPopup->addAction( i18n("Unmount Device") );
+  mPopup->addSeparator();
+  QAction *openFileManagerAction = mPopup->addAction( i18n("Open in File Manager") );
+  mountPointAction->setEnabled( disk->mounted() ? false : true );
+  umountPointAction->setEnabled(disk->mounted());
+  openFileManagerAction->setEnabled(disk->mounted() );
+  QAction *position = mPopup->exec( p );
+
 
 
   bool openFileManager = false;
-  if( position == -1 )
+  if( !position )
   {
     mDiskList.setUpdatesDisabled(false);
     delete mPopup; mPopup = 0;
     return;
   }
-  else if( position == 0 || position == 1 )
+  else if( position == mountPointAction || position == umountPointAction )
   {
       item->setText( sizeCol, i18n("MOUNTING") );
       item->setText( freeCol, i18n("MOUNTING") );
@@ -496,7 +485,7 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
 	  KMessageBox::error( this, disk->lastSysError() );
 	}
       else if ( ( mStd.openFileManager() == true)
-		&& (position == 0) ) //only on mount
+		&& (position == mountPointAction) ) //only on mount
 	{
 	  openFileManager = true;
 	}
@@ -504,39 +493,39 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
       delete item;
       mDiskList.deleteAllMountedAt(disk->mountPoint());
   }
-  else if( position == 2 )
+  else if( position == openFileManagerAction )
   {
     openFileManager = true;
   }
 
   if( openFileManager == true )
   {
-    kdDebug() << "opening filemanager" << endl;
+    kDebug() << "opening filemanager" ;
     if(  mStd.fileManager().isEmpty() == false )
     {
       QString cmd = mStd.fileManager();
-      int pos = cmd.find("%m");
+      int pos = cmd.indexOf("%m");
       if( pos > 0 )
       {
-	cmd = cmd.replace( pos, 2, KProcess::quote(disk->mountPoint()) ) + " &";
+	cmd = cmd.replace( pos, 2, KShell::quoteArg(disk->mountPoint()) ) + " &";
       }
       else
       {
-	cmd += " " + KProcess::quote(disk->mountPoint()) +" &";
+	cmd += ' ' + KShell::quoteArg(disk->mountPoint()) + " &";
       }
       system( QFile::encodeName(cmd) );
     }
   }
-  
+
   //Update only here as showing of error message triggers event loop.
   mDiskList.setUpdatesDisabled(false);
   delete mPopup; mPopup = 0;
 
-  if( position != 2 ) // No need to update when just opening the fm.
+  if( position != openFileManagerAction ) // No need to update when just opening the fm.
   {
     updateDF();
   }
-  
+
 }
 
 
@@ -553,7 +542,7 @@ void KDFWidget::updateDiskBarPixmaps( void )
 
   int size=0, w=0;
 
-   for(uint i=0; i<mTabProp.size()-1; i++ )
+   for( int i=0; i<mTabProp.size()-1; i++ )
      size += mList->columnWidth(i);
    w=mList->width() - size - 4;
    if (w<0)
@@ -567,7 +556,7 @@ void KDFWidget::updateDiskBarPixmaps( void )
   }
 
   int i=0;
-  for(QListViewItem *it=mList->firstChild(); it!=0;it=it->nextSibling(),i++ )
+  for(Q3ListViewItem *it=mList->firstChild(); it!=0;it=it->nextSibling(),i++ )
   {
     // I can't get find() to work. The Disks::compareItems(..) is
     // never called.
@@ -604,18 +593,18 @@ void KDFWidget::updateDiskBarPixmaps( void )
       QPixmap *pix = new QPixmap( w, h );
       if( pix == 0 ) { continue; }
 
-      pix->fill(white);
+      pix->fill(Qt::white);
       QPainter p(pix);
-      p.setPen(black);
+      p.setPen(Qt::black);
       p.drawRect(0,0,w,h);
       QColor c;
-      if ( (disk->iconName().find("cdrom") != -1)
-	   || (disk->iconName().find("writer") != -1) )
-	c = gray;
+      if ( (disk->iconName().contains("cdrom"))
+	   || (disk->iconName().contains("writer")) )
+	c = Qt::gray;
       else
-	c = disk->percentFull() > FULL_PERCENT ? red : darkGreen;
+	c = disk->percentFull() > FULL_PERCENT ? Qt::red : Qt::darkGreen;
       p.setBrush(c );
-      p.setPen(white);
+      p.setPen(Qt::white);
       p.drawRect(1,1,(int)(((float)pix->width()-2)*(disk->percentFull()/100)),
 		 pix->height()-2);
       it->setPixmap ( usageCol, *pix );
@@ -639,13 +628,15 @@ void KDFWidget::columnSizeChanged( int, int, int )
     mTimer->stop();
   }
 
-  mTimer->start( 10, true );
+  mTimer->setSingleShot(true);
+
+  mTimer->start( 10);
 }
 
 
 void KDFWidget::invokeHelp()
 {
-  kapp->invokeHelp("", "kcontrol/kdf");
+  KToolInvocation::invokeHelp("", "kcontrol/kdf");
 }
 
 #include "kdfwidget.moc"
