@@ -21,14 +21,13 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+#ifndef KDFWIDGET_H
+#define KDFWIDGET_H
 
-#ifndef __KDFWIDGET_H__
-#define __KDFWIDGET_H__
+#include <QtCore/QVector>
+#include <QtCore/qglobal.h>
 
-#include <qmemarray.h>
-#include <qglobal.h>
-#include <qstring.h>
-#include <qlistview.h>
+#include <Qt3Support/Q3ListView>
 
 #include "disks.h"
 #include "disklist.h"
@@ -39,7 +38,7 @@
 class CListView;
 class COptionDialog;
 class QTimer;
-class KPopupMenu;
+class KMenu;
 
 /**************************************************************/
 
@@ -72,12 +71,12 @@ class CTabEntry
 //    columns with a numeric value are sorted by numerical value.
 //
 
-class CListViewItem : public QListViewItem
+class CListViewItem : public Q3ListViewItem
 {
   public:
-    CListViewItem ( CListView * parent, QListViewItem * after );
+    CListViewItem ( CListView * parent, Q3ListViewItem * after );
  
-    virtual int compare ( QListViewItem* i, int col, bool) const;
+    virtual int compare ( Q3ListViewItem* i, int col, bool) const;
     	
     void    setKeys ( int kb_size, int kb_avail, float percent_full ) ;
 
@@ -107,8 +106,8 @@ class KDFWidget : public QWidget
     };
 
   public:
-    KDFWidget( QWidget *parent=0, const char *name=0, bool init=false);
-    ~KDFWidget( void );
+    explicit KDFWidget( QWidget *parent=0, bool init=false);
+    ~KDFWidget( );
 
   public slots:
     void settingsChanged( void );
@@ -120,9 +119,8 @@ class KDFWidget : public QWidget
   
   private slots:
     void criticallyFull( DiskEntry *disk );
-    void rightButtonPressed( QListViewItem *item, const QPoint &p, int );
-    void rightButtonClicked( QListViewItem *item, const QPoint &p, int );
-    void popupMenu( QListViewItem *item, const QPoint &p );
+    void rightButtonPressed( Q3ListViewItem *item, const QPoint &p, int );
+    void popupMenu( Q3ListViewItem *item, const QPoint &p );
     void setUpdateFrequency( int frequency );
     void columnSizeChanged( int column, int, int newSize );
     void updateDiskBarPixmaps( void );
@@ -135,19 +133,18 @@ class KDFWidget : public QWidget
 
   private:
     void makeColumns( void );
-    DiskEntry *selectedDisk( QListViewItem *item=0 );
+    DiskEntry *selectedDisk( Q3ListViewItem *item=0 );
 
   private:
     bool readingDF;
-    QMemArray<CTabEntry*> mTabProp;
+    QVector<CTabEntry*> mTabProp;
     CListView     *mList;
     COptionDialog *mOptionDialog;
-    KPopupMenu    *mPopup;
+    KMenu    *mPopup;
     QTimer        *mTimer;
     DiskList   mDiskList;
     bool       mIsTopLevel;
     CStdOption mStd;
 };
 
-
 #endif
