@@ -26,38 +26,36 @@
 #include <kstandarddirs.h>
 #include <kuniqueapplication.h>
 
-#include <qfile.h>
-#include <qfileinfo.h>
+#include <QFile>
+#include <QFileInfo>
 
 #include "kwalletmanager.h"
 
 
 class MyApp : public KUniqueApplication {
 	public:
-		MyApp() : KUniqueApplication() { ref(); }
+		MyApp() : KUniqueApplication() { KGlobal::ref(); }
 		virtual ~MyApp() {}
 
 		virtual int newInstance() { return 0; }
 };
 
 int main(int argc, char **argv) {
-	static KCmdLineOptions options[] = {
-		{"show", I18N_NOOP("Show window on startup"), 0},
-		{"kwalletd", I18N_NOOP("For use by kwalletd only"), 0},
-		{"+name", I18N_NOOP("A wallet name"), 0},
-		KCmdLineLastOption
-	};
-
-	KAboutData about("kwalletmanager", I18N_NOOP("KDE Wallet Manager"), "1.1",
-		I18N_NOOP("KDE Wallet Management Tool"),
+	KAboutData about("kwalletmanager", 0, ki18n("KDE Wallet Manager"), "1.2",
+		ki18n("KDE Wallet Management Tool"),
 		KAboutData::License_GPL,
-		I18N_NOOP("(c) 2003,2004 George Staikos"), 0,
-		"http://www.kde.org/");
+		ki18n("(c) 2003,2004 George Staikos"), KLocalizedString(),
+		"http://utils.kde.org/projects/kwalletmanager");
 
-	about.addAuthor("George Staikos", I18N_NOOP("Primary author and maintainer"), "staikos@kde.org");
-	about.addAuthor("Isaac Clerencia", I18N_NOOP("Developer"), "isaac@warp.es");
+	about.addAuthor(ki18n("George Staikos"), ki18n("Primary author and maintainer"), "staikos@kde.org");
+	about.addAuthor(ki18n("Isaac Clerencia"), ki18n("Developer"), "isaac@warp.es");
 
 	KCmdLineArgs::init(argc, argv, &about);
+
+	KCmdLineOptions options;
+	options.add("show", ki18n("Show window on startup"));
+	options.add("kwalletd", ki18n("For use by kwalletd only"));
+	options.add("+name", ki18n("A wallet name"));
 	KCmdLineArgs::addCmdLineOptions(options);
 
 	if (!KUniqueApplication::start()) {
@@ -69,8 +67,6 @@ int main(int argc, char **argv) {
 	KWalletManager wm;
 	wm.setCaption(i18n("KDE Wallet Manager"));
 
-	a.setMainWidget(&wm);
-
 	KGlobal::dirs()->addResourceType("kwallet", "share/apps/kwallet");
 
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
@@ -84,7 +80,7 @@ int main(int argc, char **argv) {
 	}
 
 	for (int i = 0; i < args->count(); ++i) {
-		QString fn = QFileInfo(args->arg(i)).absFilePath();
+		QString fn = QFileInfo(args->arg(i)).absoluteFilePath();
 		KMimeType::Ptr ptr;
 		if (QFile::exists(fn) &&
 			(ptr = KMimeType::findByFileContent(fn)) &&
